@@ -6,12 +6,12 @@ from . import (
     decorators,
     files,
     github,
-    logging,
-    math,
+    logger,
+    mathematics,
     processes,
     shell,
-    string,
     system,
     testing,
+    text,
     validators,
 )
